/**
 * @module libflitter/errors/SoftError
 */

const FlitterError = require('./FlitterError')

/**
 * An error that, if thrown within Flitter, indicates that a non-fatal error has occurred.
 * Flitter will not shut down after this error, but the exit code will change.
 *
 * If thrown while a Unit is initializing, the unit's status will be set to Unit.STATUS_ERROR,
 * and any units that depend on it will fail to start.
 *
 * @extends module:libflitter/errors/FlitterError~FlitterError
 */
class StopError extends FlitterError {

    constructor(msg = "Flitter encountered an error, but was able to continue.", ...args){
        super(msg, ...args)
    }

}

module.exports = exports = StopError
